#  The Instituational Track: DeGov

## Description

The Institutional Track, known as DeGov (Decentralized Governance), is designed to explore the application of decentralized governance models in institutional settings. This track focuses on creating innovative solutions that enable more democratic, transparent, and efficient governance structures within organizations, governments, and other institutional entities.

## What to do on this track?

Participants aree tasked with developing decentralized governance systems, tools for voting and decision-making, and systems for managing institutional processes in a decentralized manner. The goal is to create scalable and secure solutions that can be adopted by large entities to improve governance and stakeholder participation.

## Use-case ideas

If you need some ideas, here is a list of use-cases:

- Proof of personhood
- DAO infrastructure (global network with many local groups of people)
- Decentralized Voting Systems
- Public Policy Decision-Making
- Transparent Budget Allocation
- Decentralized Project Management
- Immutability: Connecting private blockchain to public
- Conflict Resolution Mechanism
- Insurance and proving events

## Where to start?

https://polkadot.com/ - Always start here and look at already existing projects, SDKs and tools you can use to build your project.

https://unique.network/ - If you want to create an NFT based project.

https://g.g6.network/g6-networks-release/ - If you want to build on G6 Network's technology stack.

https://www.mandalachain.io/ - If you want to build for onboarding users.

## Unique Network - Specific Challenge

Topic: NFT as a data containter

Type: Data obfuscation in an on-chain NFT record - managing data access and visibility.

Description: The challenge is based around the concept of on-chain and off-chain data storage accessibility in terms of data obfuscation. Unique Network NFTs provide a very flexible mechanism for storing data both on-chain and off-chain including handling mutability and rights in that respect (who can modify). The question of who is allowed to see the raw data is a completely different issue and is handled at the application level. Your task is to come up with a simple mechanism which allows data obfuscation of data stored via the NFT providing a way for an application to manage which data can be publicly visible and which is obfuscated and availible only to the application. There are no limitations set in regard to how obfuscation is performed, it is entirely in at the discretion of the developer/hacker.

- Demo of a collection and token: https://github.com/UniqueNetwork/workshop-nft-data
- SDK: https://docs.unique.network/build/sdk/getting-started.html
- Accounts and Wallets: https://docs.unique.network/tutorials/work-with-accounts.html
- Unique Schema 2.0: https://docs.unique.network/tutorials/createCollectionV2 https://docs.unique.network/reference/schemas/
- React Boilerplate: https://github.com/UniqueNetwork/accounts-react-example

Mentor from Unique: Max Andreev - Senior Developer (availability for mentoring slots on Telegram - check mentoring group chat)

## G6 Network - Specific Challenge

Topic: Citizens of Polkadot

Type: Front-end for Substrate based blockchains

Description: Research Proof of Personhood and use the frontend solutions of G6 Networks to build on. You'll need to connect to https:/testnet.g6.network/ and create a useful product for the Polkadot citizens. Who are the citizens of Polkadot? Anyone who uses Polkadot and engages with the community. We are decentralized and autonomous. Create your futuristic dream product for a global network of many local groups.

- G6 Networks open source code and front-end: https://g.g6.network/g6-networks-release/
- G6 Networks White paper: https://g6-networks.gitbook.io/g6-networks/
- G6 networks official Telegram group: https://t.me/g6networks

Mentors: Serge, Johan and six (availability for mentoring slots on Telegram - check mentoring group chat)

## How to submit?

Submit your solution in email to: contact@cryptoctf.org

What to include: Project name, description, which ecosystem or team you built it for*, git link and presentation link (can be in git).

*On this track you can choose from: Polkadot (anything Polkadot/Substrate, up to $2000 rewards), Unique Network (Up to $2000 rewards), G6 Networks (Up to $10000 rewards), Mandala Chain (Up to $10000 rewards), GotEm (up to $2000 rewards). You can also choose two projects, eg. Polkadot and G6 Networks, but you'll get a harder time scoring.


# The Physical Track: RWA and DePin

## Description

The Physical Track focuses on Real-World Assets (RWA) and Decentralized Physical Infrastructure Networks (DePin). This track aims to bridge the gap between the digital and physical worlds by leveraging blockchain technology to tokenize and manage physical assets, as well as to build decentralized networks for physical infrastructure.

## What to do on this track?

Participants work on projects that involve the tokenization of real-world assets, such as real estate, commodities, or physical products. Additionally, they will develop decentralized networks and protocols that facilitate the management and operation of physical infrastructure, ensuring transparency, security, and efficiency. They can mix the two technologies use choose to build only RWA or only DePin focues programs, applications.

## Use-case ideas

If you need some ideas, here is a list of use-cases:

- Decentralized Energy Networks
- Supply Chain Transparency
- Crowdsourced Physical Infrastructure
- Decentralized Storage Networks
- Tokenized Real Estate (that's probably the worst idea)

## Where to start?

https://polkadot.com/ - Always start here and look at already existing projects, SDKs and tools you can use to build your project.

https://unique.network/ - If you want to create an NFT based project.

https://g.g6.network/g6-networks-release/ - If you want to build on G6 Network's technology stack.

https://mosaicchain.io/ - They have a unique validator selection consensus connected to NFT and possible DePin features.

## How to submit?

Submit your solution in email to: contact@cryptoctf.org

What to include: Project name, description, which ecosystem or team you built it for*, git link and presentation link (can be in git).

*On this track you can choose from: Polkadot (anything Polkadot/Substrate, up to $2000 rewards), Unique Network (Up to $2000 rewards), G6 Networks (Up to $10000 rewards), Mandala Chain (Up to $10000 rewards). You can also choose two projects, eg. Polkadot and G6 Networks, but you'll get a harder time scoring.


# AI on Blockchain Track: For real?

## Description

The AI on Blockchain Track explores the integration of artificial intelligence with blockchain technology. This track challenges participants to create innovative applications that leverage the strengths of both AI and blockchain to solve complex problems, enhance security, and provide new capabilities in various domains.

## What to do on this track?

Participants focus on developing AI-driven systems, decentralized AI models, and blockchain-based platforms for training and deploying AI algorithms. The goal is to demonstrate the potential of combining AI and blockchain to create intelligent, autonomous, and secure systems.

## Use-case ideas

If you need some ideas, here is a list of use-cases:

- Anti-AI algos, differntiating between human and AI/deepfakes
- Autonomous AI Agents
- Decentralized AI Model Training
- AI-Driven Smart Contracts
- AI-Based Fraud Detection
- AI-Powered Predictive Analytics


## Where to start?

https://polkadot.com/ - Always start here and look at already existing projects, SDKs and tools you can use to build your project.

https://polkabot.ai/ - AI-powered education on chain, in the Polkadot ecosystem.

https://www.cere.network/ - Decentralized storage solution for streaming and AI.

https://github.com/Qrucial/QRUCIAL-DAO/ - QRUCIAL DAO's solution for connecting off-chain executables to on-chain decisions.

## How to submit?

Submit your solution in email to: contact@cryptoctf.org

What to include: Project name, description, which ecosystem or team you built it for*, git link and presentation link (can be in git).

*On this track you can choose from: Polkadot (anything Polkadot/Substrate, up to $2000 rewards), Unique Network (Up to $2000 rewards), G6 Networks (Up to $10000 rewards), Mandala Chain (Up to $10000 rewards), Cere Network (up to $2000 rewards). You can also choose two projects, eg. Polkadot and G6 Networks, but you'll get a harder time scoring.


